@@ -375,6 +375,9 @@ mod tests {
 
     use crate::{to_vec, from_vec, Error};
 
+    #[derive(Serialize, Deserialize, PartialEq, Debug)]
+    struct Thing([u8; 3]);
+
     #[derive(Serialize, Deserialize, PartialEq, Debug)]
     struct Test {
         x: bool,
@@ -383,7 +386,8 @@ mod tests {
         c: Option<u16>,
         d: Option<u16>,
         e: Vec<u8>,
-        f: [u8; 3]
+        /// Sub-structs are transparent
+        f: Thing
     }
 
     #[test]
@@ -392,7 +396,7 @@ mod tests {
             x: true,
             a: 65538, b:160, c: None, d: Some(3),
             e: vec![0x33, 0x44],
-            f: [0x55, 0x66, 0x77]
+            f: Thing([0x55, 0x66, 0x77])
         };
         let result = to_vec(&test).unwrap();
         assert_eq!("0100010002a00001000300023344556677", encode(&result));
